==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/de/login.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_not_active'=>'Dein Konto ist nicht aktiviert! Entweder hast du vergessen dies zu tun oder du wurdest ausgeschlossen.',
'auth_fail_agent_changed'=>'Die Browserkennung in deiner Zugangserlaubnis hat sich seit der Anmeldung geändert.',
'auth_fail_ip_changed'=>'Deine Internet-Adresse in deiner Zugangserlaubnis hat sich seit der Anmeldung geändert.',
'auth_fail_lifetime_exceeded'=>'Deine Zugangserlaubnis ist zu alt und abgelaufen.',
'auth_fail_login_token_invalid'=>'Deine Zugangserlaubnis ist ungültig.',
'auth_fail_taint'=>'Deine Zugangserlaubnis wurde als "verdorben" markiert.',
'explain_forgot_password'=>'Wenn du dein Kennwort verloren hast, kannst du hier ein neues anfordern. Bitte gebe deinen Benutzernamen an und eine E-Mail wird an deine hinterlegte Adresse versendet, die weitere Anweisungen enthält.',
'explain_reauth'=>'Deine Benutzerdaten haben sich seit der Anmeldung geändert. Dadurch wurde deine Zugangserlaubnis ungültig und du kannst nun dein Kennwort angeben, um sie zu erneuern.',
'forgot_password'=>'Kennwort vergessen',
'inactive_account_cannot_request_password'=>'Dein Benutzerkonto ist abgeschaltet und kann kein neues Kennwort zugewiesen bekommen!',
'inactive_cannot_get_new_password'=>'Dein Zugangskonto ist abgeschaltet und kann kein neues Kennwort erhalten!',
'incorrect_password'=>'Dein angegebenes Kennwort ist nicht richtig!',
'incorrect_username'=>'Du hast keinen gültigen Benutzernamen angegeben!',
'password_activation_sent'=>'Wir haben die E-Mail erfolgreich an deine Adresse verschickt.',
'password_activation_success'=>'Dein neues Kennwort ist nun einsatzbereit.',
'please_read_note'=>'Bitte Hinweis lesen',
'reauth'=>'Zugangserlaubnis erneuern',
'reauth_failed'=>'Du hast nicht das korrekte Kennwort angegeben. Die Zugangserlaubnis bleibt "verdorben".',
'reauth_success'=>'Deine Zugangserlaubnis wurde erneuert und ist nun wieder gültig.',
'remember_login'=>'Anmeldung merken',
'too_many_fail_logins'=>'Du hast zu häufig ein falsches Kennwort angegeben. Weitere Versuche werden nun für fünfzehn Minuten abgelehnt.',
'your_auto_login_signature_is_invalid'=>'Dein Autologin-Cookie ist ungültig und wurde gelöscht.',
'you_are_now_logged_in'=>'Du bist nun in unserem Forum angemeldet!',
'you_are_now_logged_out'=>'Wir haben dich aus unserem Forum abgemeldet!',
'you_can_only_request_one_password'=>'Du darfst nur einmalig ein neues Kennwort anfordern!'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/de/login.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_not_active'=>'Dein Konto ist nicht aktiviert! Entweder hast du vergessen dies zu tun oder du wurdest ausgeschlossen.',
'auth_fail_agent_changed'=>'Die Browserkennung in deiner Zugangserlaubnis hat sich seit der Anmeldung geändert.',
'auth_fail_ip_changed'=>'Deine Internet-Adresse in deiner Zugangserlaubnis hat sich seit der Anmeldung geändert.',
'auth_fail_lifetime_exceeded'=>'Deine Zugangserlaubnis ist zu alt und abgelaufen.',
'auth_fail_login_token_invalid'=>'Deine Zugangserlaubnis ist ungültig.',
'auth_fail_taint'=>'Deine Zugangserlaubnis wurde als "verdorben" markiert.',
'estimated_password_strength'=>'Geschätzte Kennwortstärke',
'explain_forgot_password'=>'Wenn du dein Kennwort verloren hast, kannst du hier ein neues anfordern. Bitte gebe deinen Benutzernamen an und eine E-Mail wird an deine hinterlegte Adresse versendet, die weitere Anweisungen enthält.',
'explain_password'=>'Bitte benutze ein Kennwort, daß möglichst viele Zeichen enthält. Benutze keine Wörter, die leicht zu erraten sind (wie Name des Kindes oder Geburtsdatum) oder in Wörterbüchern vorkommen. Auch keine Variationen mit hinzugefügter Zahl oder rückwärts geschrieben. Eine gute Möglichkeit ist, einen Satz zu nehmen, den du dir merken kannst und den Anfangsbuchstaben jedes Wortes zu verwenden. Ein Beispiel: "Mein Vater erklärt mir jeden Samstag unsere 9 Planeten" wird zu "MVemjSu9P". Das Kennwort muß wenigstens fünf Zeichen lang, aber nicht mehr als einunddreißig (31) sein.',
'explain_reauth'=>'Deine Benutzerdaten haben sich seit der Anmeldung geändert. Dadurch wurde deine Zugangserlaubnis ungültig und du kannst nun dein Kennwort angeben, um sie zu erneuern.',
'forgot_password'=>'Kennwort vergessen',
'inactive_account_cannot_request_password'=>'Dein Benutzerkonto ist abgeschaltet und kann kein neues Kennwort zugewiesen bekommen!',
'incorrect_password'=>'Dein angegebenes Kennwort ist nicht richtig!',
'incorrect_username'=>'Du hast keinen gültigen Benutzernamen angegeben!',
'new_passwords_not_equal'=>'Deine neuen Kennwörter sind ungleich!',
'password_activation_sent'=>'Wir haben die E-Mail erfolgreich an deine Adresse verschickt.',
'password_again'=>'Bitte wiederholen',
'password_must_not_be_empty'=>'Dein Kennwort darf nicht leer sein.',
'password_new'=>'Neues Kennwort',
'password_requires_javascript'=>'Du mußt Javascript für das Anmelden aktivieren, da wir dein Passwort vor dem Versenden verschlüsseln.',
'please_read_note'=>'Bitte Hinweis lesen',
'reauth'=>'Zugangserlaubnis erneuern',
'reauth_failed'=>'Du hast nicht das korrekte Kennwort angegeben. Die Zugangserlaubnis bleibt "verdorben".',
'reauth_success'=>'Deine Zugangserlaubnis wurde erneuert und ist nun wieder gültig.',
'remember_login'=>'Anmeldung merken',
'reset_password'=>'Kennwort zurücksetzen',
'reset_password_success'=>'Dein Kennwort wurde erfolgreich geändert.',
'too_many_fail_logins'=>'Du hast zu häufig ein falsches Kennwort angegeben. Weitere Versuche werden nun für fünfzehn Minuten abgelehnt.',
'your_auto_login_signature_is_invalid'=>'Dein Autologin-Cookie ist ungültig und wurde gelöscht.',
'you_are_now_logged_in'=>'Du bist nun in unserem Forum angemeldet!',
'you_are_now_logged_out'=>'Wir haben dich aus unserem Forum abgemeldet!',
'you_can_only_request_one_password'=>'Du darfst nur einmalig ein neues Kennwort anfordern!',
'you_specified_no_mail_address'=>'Du hast keine E-Mail Adresse angegeben.'
);
?>
